==================
What is SaltStack?
==================

Salt is a new approach to infrastructure management. Easy enough to get
running in minutes, scalable enough to manage tens of thousands of servers,
and fast enough to communicate with them in *seconds*.

Salt delivers a dynamic communication bus for infrastructures that can be used
for orchestration, remote execution, configuration management and much more.

Documentation
=============

Installation instructions, getting started guides, and in-depth API
documention.

http://docs.saltstack.com

IRC Chat
========

Join the vibrant, helpful and positive SaltStack chat room in Freenode at
#salt. There is no need to introduce yourself, or ask permission to join in,
just help and be helped! Make sure to wait for an answer, sometimes it may take
a few moments for someone to reply.

http://webchat.freenode.net/?channels=salt&uio=Mj10cnVlJjk9dHJ1ZSYxMD10cnVl83

Salt Air
========

The SaltStack YouTube channel is filled with Salt videos and presentations.
Watch the latest Salt Air episodes for updates from Thomas on development,
catch tutorials, and stay on the cutting edge of Salt.

http://www.youtube.com/user/saltstack

Mailing List
============

The SaltStack community users mailing list is hosted by Google groups. Anyone
can post to ask questions about SaltStack products and anyone can help answer.
Join the conversation!

https://groups.google.com/forum/#!forum/salt-users

You may subscribe the the list without a Google account by emailing
salt-users+subscribe@googlegroups.com and you may post to the list by emailing
salt-users@googlegroups.com

Developing Salt
===============

The Salt development team is welcoming, positive, and dedicated to helping
people get new code and fixes into SaltStack projects. Log into GitHub and get
started with one of the largest developer communities in the world.

https://github.com/saltstack
